summaryrefslogtreecommitdiff
path: root/audio/tests/wavetest/comptest.cpp
diff options
context:
space:
mode:
authorDaniel Rugerio <[email protected]>2021-08-13 15:05:12 -0700
committerGitHub <[email protected]>2021-08-13 15:05:12 -0700
commit7895dd22785ddba5e973662ed942be3b3452b89d (patch)
tree5c4572d5bfd076d3776a88c5757e37f3ed50c0e7 /audio/tests/wavetest/comptest.cpp
parentdf47b2d284558fa9aacd19257153037e4ebba60e (diff)
audio: Updates for Windows 10 22000 (#655)
* Updates for Windows 10 22000. * Change how WIL is consumed.
Diffstat (limited to 'audio/tests/wavetest/comptest.cpp')
-rw-r--r--audio/tests/wavetest/comptest.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/audio/tests/wavetest/comptest.cpp b/audio/tests/wavetest/comptest.cpp
index db823156..6b0b4e86 100644
--- a/audio/tests/wavetest/comptest.cpp
+++ b/audio/tests/wavetest/comptest.cpp
@@ -1,6 +1,6 @@
// ------------------------------------------------------------------------------
//
-// Copyright (C) Microsoft. All rights reserved.
+// Copyright (C) Microsoft Corporation. All rights reserved.
//
// Module Name:
//
@@ -28,9 +28,9 @@ void Test_VerifyPinWaveRTConformance(void)
VERIFY_SUCCEEDED(pHalfApp->m_pAudioDeviceEndpoint->GetRTCaps(&bIsRTCapable));
// Check for our new requirement - new drivers must be WaveRT. Here we skip the test on AVStream (UAC1/HFP/A2dp)
// For other old drivers that are not WaveRT, may issue Errata to cover the failure.
- if (!pHalfApp->m_bIsAVStream)
+ if (pHalfApp->m_bIsPortCls)
{
VERIFY_IS_TRUE(bIsRTCapable);
}
@@ -28,9 +28,9 @@ void Test_VerifyPinWaveRTConformance(void)
VERIFY_SUCCEEDED(pHalfApp->m_pAudioDeviceEndpoint->GetRTCaps(&bIsRTCapable));
- // Check for our new requirement - new drivers must be WaveRT. Here we skip the test on AVStream (UAC1/HFP/A2dp)
+ // Check for our new requirement - new PortCls drivers must be WaveRT.
// For other old drivers that are not WaveRT, may issue Errata to cover the failure.